@@ -1,8 +1,8 @@
-/* A Bison parser, made by GNU Bison 3.7.6.  */
+/* A Bison parser, made by GNU Bison 3.7.4.  */
 
 /* Bison implementation for Yacc-like parsers in C
 
-   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2021 Free Software Foundation,
+   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2020 Free Software Foundation,
    Inc.
 
    This program is free software: you can redistribute it and/or modify
@@ -16,7 +16,7 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
 /* As a special exception, you may create a larger work that contains
    part or all of the Bison parser skeleton and distribute that work
@@ -46,10 +46,10 @@
    USER NAME SPACE" below.  */
 
 /* Identify Bison output, and Bison version.  */
-#define YYBISON 30706
+#define YYBISON 30704
 
 /* Bison version string.  */
-#define YYBISON_VERSION "3.7.6"
+#define YYBISON_VERSION "3.7.4"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -71,7 +71,7 @@
 
 /* arparse.y - Strange script language parser */
 
-/* Copyright (C) 1992-2021 Free Software Foundation, Inc.
+/* Copyright (C) 1992-2022 Free Software Foundation, Inc.
 
    This file is part of GNU Binutils.
 
@@ -101,7 +101,7 @@
 #include "arsup.h"
 extern int verbose;
 extern int yylex (void);
-static int yyerror (const char *);
+static void yyerror (const char *);
 
 #line 107 "arparse.c"
 
@@ -309,18 +309,6 @@ typedef int_least16_t yytype_int16;
 typedef short yytype_int16;
 #endif
 
-/* Work around bug in HP-UX 11.23, which defines these macros
-   incorrectly for preprocessor constants.  This workaround can likely
-   be removed in 2023, as HPE has promised support for HP-UX 11.23
-   (aka HP-UX 11i v2) only through the end of 2022; see Table 2 of
-   <https://h20195.www2.hpe.com/V2/getpdf.aspx/4AA4-7673ENW.pdf>.  */
-#ifdef __hpux
-# undef UINT_LEAST8_MAX
-# undef UINT_LEAST16_MAX
-# define UINT_LEAST8_MAX 255
-# define UINT_LEAST16_MAX 65535
-#endif
-
 #if defined __UINT_LEAST8_MAX__ && __UINT_LEAST8_MAX__ <= __INT_MAX__
 typedef __UINT_LEAST8_TYPE__ yytype_uint8;
 #elif (!defined __UINT_LEAST8_MAX__ && defined YY_STDINT_H \
@@ -418,9 +406,9 @@ typedef int yy_state_fast_t;
 
 /* Suppress unused-variable warnings by "using" E.  */
 #if ! defined lint || defined __GNUC__
-# define YY_USE(E) ((void) (E))
+# define YYUSE(E) ((void) (E))
 #else
-# define YY_USE(E) /* empty */
+# define YYUSE(E) /* empty */
 #endif
 
 #if defined __GNUC__ && ! defined __ICC && 407 <= __GNUC__ * 100 + __GNUC_MINOR__
@@ -742,7 +730,7 @@ static const yytype_int8 yypgoto[] =
   /* YYDEFGOTO[NTERM-NUM].  */
 static const yytype_int8 yydefgoto[] =
 {
-       0,     1,     2,     4,    20,    21,    22,    23,    24,    25,
+      -1,     1,     2,     4,    20,    21,    22,    23,    24,    25,
       26,    27,    28,    29,    30,    31,    32,    51,    44,    35,
       46,    33
 };
@@ -874,7 +862,7 @@ yy_symbol_value_print (FILE *yyo,
                        yysymbol_kind_t yykind, YYSTYPE const * const yyvaluep)
 {
   FILE *yyoutput = yyo;
-  YY_USE (yyoutput);
+  YYUSE (yyoutput);
   if (!yyvaluep)
     return;
 # ifdef YYPRINT
@@ -882,7 +870,7 @@ yy_symbol_value_print (FILE *yyo,
     YYPRINT (yyo, yytoknum[yykind], *yyvaluep);
 # endif
   YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
-  YY_USE (yykind);
+  YYUSE (yykind);
   YY_IGNORE_MAYBE_UNINITIALIZED_END
 }
 
@@ -996,13 +984,13 @@ static void
 yydestruct (const char *yymsg,
             yysymbol_kind_t yykind, YYSTYPE *yyvaluep)
 {
-  YY_USE (yyvaluep);
+  YYUSE (yyvaluep);
   if (!yymsg)
     yymsg = "Deleting";
   YY_SYMBOL_PRINT (yymsg, yykind, yyvaluep, yylocationp);
 
   YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
-  YY_USE (yykind);
+  YYUSE (yykind);
   YY_IGNORE_MAYBE_UNINITIALIZED_END
 }
 
@@ -1265,115 +1253,115 @@ yyreduce:
   case 2: /* $@1: %empty  */
 #line 68 "arparse.y"
         { prompt(); }
-#line 1269 "arparse.c"
+#line 1257 "arparse.c"
     break;
 
   case 6: /* command_line: command NEWLINE  */
 #line 77 "arparse.y"
                                 { prompt(); }
-#line 1275 "arparse.c"
+#line 1263 "arparse.c"
     break;
 
   case 19: /* command: END  */
 #line 93 "arparse.y"
                          { ar_end(); return 0; }
-#line 1281 "arparse.c"
+#line 1269 "arparse.c"
     break;
 
   case 21: /* command: FILENAME  */
 #line 95 "arparse.y"
                          { yyerror("foo"); }
-#line 1287 "arparse.c"
+#line 1275 "arparse.c"
     break;
 
   case 23: /* extract_command: EXTRACT modulename  */
 #line 102 "arparse.y"
                 { ar_extract((yyvsp[0].list)); }
-#line 1293 "arparse.c"
+#line 1281 "arparse.c"
     break;
 
   case 24: /* replace_command: REPLACE modulename  */
 #line 107 "arparse.y"
                 { ar_replace((yyvsp[0].list)); }
-#line 1299 "arparse.c"
+#line 1287 "arparse.c"
     break;
 
   case 25: /* clear_command: CLEAR  */
 #line 112 "arparse.y"
                 { ar_clear(); }
-#line 1305 "arparse.c"
+#line 1293 "arparse.c"
     break;
 
   case 26: /* delete_command: DELETE modulename  */
 #line 117 "arparse.y"
                 { ar_delete((yyvsp[0].list)); }
-#line 1311 "arparse.c"
+#line 1299 "arparse.c"
     break;
 
   case 27: /* addmod_command: ADDMOD modulename  */
 #line 121 "arparse.y"
                 { ar_addmod((yyvsp[0].list)); }
-#line 1317 "arparse.c"
+#line 1305 "arparse.c"
     break;
 
   case 28: /* list_command: LIST  */
 #line 126 "arparse.y"
                 { ar_list(); }
-#line 1323 "arparse.c"
+#line 1311 "arparse.c"
     break;
 
   case 29: /* save_command: SAVE  */
 #line 131 "arparse.y"
                 { ar_save(); }
-#line 1329 "arparse.c"
+#line 1317 "arparse.c"
     break;
 
   case 30: /* open_command: OPEN FILENAME  */
 #line 138 "arparse.y"
                 { ar_open((yyvsp[0].name),0); }
-#line 1335 "arparse.c"
+#line 1323 "arparse.c"
     break;
 
   case 31: /* create_command: CREATE FILENAME  */
 #line 143 "arparse.y"
                 { ar_open((yyvsp[0].name),1); }
-#line 1341 "arparse.c"
+#line 1329 "arparse.c"
     break;
 
   case 32: /* addlib_command: ADDLIB FILENAME modulelist  */
 #line 149 "arparse.y"
                 { ar_addlib((yyvsp[-1].name),(yyvsp[0].list)); }
-#line 1347 "arparse.c"
+#line 1335 "arparse.c"
     break;
 
   case 33: /* directory_command: DIRECTORY FILENAME modulelist optional_filename  */
 #line 153 "arparse.y"
                 { ar_directory((yyvsp[-2].name), (yyvsp[-1].list), (yyvsp[0].name)); }
-#line 1353 "arparse.c"
+#line 1341 "arparse.c"
     break;
 
   case 34: /* optional_filename: FILENAME  */
 #line 160 "arparse.y"
                 { (yyval.name) = (yyvsp[0].name); }
-#line 1359 "arparse.c"
+#line 1347 "arparse.c"
     break;
 
   case 35: /* optional_filename: %empty  */
 #line 161 "arparse.y"
                 { (yyval.name) = 0; }
-#line 1365 "arparse.c"
+#line 1353 "arparse.c"
     break;
 
   case 36: /* modulelist: '(' modulename ')'  */
 #line 166 "arparse.y"
                 { (yyval.list) = (yyvsp[-1].list); }
-#line 1371 "arparse.c"
+#line 1359 "arparse.c"
     break;
 
   case 37: /* modulelist: %empty  */
 #line 168 "arparse.y"
                 { (yyval.list) = 0; }
-#line 1377 "arparse.c"
+#line 1365 "arparse.c"
     break;
 
   case 38: /* modulename: modulename optcomma FILENAME  */
@@ -1383,23 +1371,23 @@ yyreduce:
 			n->name = (yyvsp[0].name);
 			(yyval.list) = n;
 		 }
-#line 1387 "arparse.c"
+#line 1375 "arparse.c"
     break;
 
   case 39: /* modulename: %empty  */
 #line 178 "arparse.y"
                 { (yyval.list) = 0; }
-#line 1393 "arparse.c"
+#line 1381 "arparse.c"
     break;
 
   case 42: /* verbose_command: VERBOSE  */
 #line 190 "arparse.y"
                 { verbose = !verbose; }
-#line 1399 "arparse.c"
+#line 1387 "arparse.c"
     break;
 
 
-#line 1403 "arparse.c"
+#line 1391 "arparse.c"
 
       default: break;
     }
@@ -1596,11 +1584,10 @@ yyreturn:
 #line 194 "arparse.y"
 
 
-static int
+static void
 yyerror (const char *x ATTRIBUTE_UNUSED)
 {
   extern int linenumber;
 
   printf (_("Syntax error in archive script, line %d\n"), linenumber + 1);
-  return 0;
 }
