@@ -1,8 +1,8 @@
-/* A Bison parser, made by GNU Bison 3.7.6.  */
+/* A Bison parser, made by GNU Bison 3.7.4.  */
 
 /* Bison implementation for Yacc-like parsers in C
 
-   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2021 Free Software Foundation,
+   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2020 Free Software Foundation,
    Inc.
 
    This program is free software: you can redistribute it and/or modify
@@ -16,7 +16,7 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
 /* As a special exception, you may create a larger work that contains
    part or all of the Bison parser skeleton and distribute that work
@@ -46,10 +46,10 @@
    USER NAME SPACE" below.  */
 
 /* Identify Bison output, and Bison version.  */
-#define YYBISON 30706
+#define YYBISON 30704
 
 /* Bison version string.  */
-#define YYBISON_VERSION "3.7.6"
+#define YYBISON_VERSION "3.7.4"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -70,7 +70,7 @@
 #line 1 "defparse.y"
  /* defparse.y - parser for .def files */
 
-/* Copyright (C) 1995-2021 Free Software Foundation, Inc.
+/* Copyright (C) 1995-2022 Free Software Foundation, Inc.
 
    This file is part of GNU Binutils.
 
@@ -338,18 +338,6 @@ typedef int_least16_t yytype_int16;
 typedef short yytype_int16;
 #endif
 
-/* Work around bug in HP-UX 11.23, which defines these macros
-   incorrectly for preprocessor constants.  This workaround can likely
-   be removed in 2023, as HPE has promised support for HP-UX 11.23
-   (aka HP-UX 11i v2) only through the end of 2022; see Table 2 of
-   <https://h20195.www2.hpe.com/V2/getpdf.aspx/4AA4-7673ENW.pdf>.  */
-#ifdef __hpux
-# undef UINT_LEAST8_MAX
-# undef UINT_LEAST16_MAX
-# define UINT_LEAST8_MAX 255
-# define UINT_LEAST16_MAX 65535
-#endif
-
 #if defined __UINT_LEAST8_MAX__ && __UINT_LEAST8_MAX__ <= __INT_MAX__
 typedef __UINT_LEAST8_TYPE__ yytype_uint8;
 #elif (!defined __UINT_LEAST8_MAX__ && defined YY_STDINT_H \
@@ -447,9 +435,9 @@ typedef int yy_state_fast_t;
 
 /* Suppress unused-variable warnings by "using" E.  */
 #if ! defined lint || defined __GNUC__
-# define YY_USE(E) ((void) (E))
+# define YYUSE(E) ((void) (E))
 #else
-# define YY_USE(E) /* empty */
+# define YYUSE(E) /* empty */
 #endif
 
 #if defined __GNUC__ && ! defined __ICC && 407 <= __GNUC__ * 100 + __GNUC_MINOR__
@@ -794,9 +782,9 @@ static const yytype_int16 yypgoto[] =
 };
 
   /* YYDEFGOTO[NTERM-NUM].  */
-static const yytype_uint8 yydefgoto[] =
+static const yytype_int16 yydefgoto[] =
 {
-       0,    12,    13,    61,    83,    63,    64,    59,    60,    55,
+      -1,    12,    13,    61,    83,    63,    64,    59,    60,    55,
       79,    76,    56,   124,   117,   131,   135,    41,    42,    43,
      104,   107,    95,    73,    91,   114
 };
@@ -968,7 +956,7 @@ yy_symbol_value_print (FILE *yyo,
                        yysymbol_kind_t yykind, YYSTYPE const * const yyvaluep)
 {
   FILE *yyoutput = yyo;
-  YY_USE (yyoutput);
+  YYUSE (yyoutput);
   if (!yyvaluep)
     return;
 # ifdef YYPRINT
@@ -976,7 +964,7 @@ yy_symbol_value_print (FILE *yyo,
     YYPRINT (yyo, yytoknum[yykind], *yyvaluep);
 # endif
   YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
-  YY_USE (yykind);
+  YYUSE (yykind);
   YY_IGNORE_MAYBE_UNINITIALIZED_END
 }
 
@@ -1090,13 +1078,13 @@ static void
 yydestruct (const char *yymsg,
             yysymbol_kind_t yykind, YYSTYPE *yyvaluep)
 {
-  YY_USE (yyvaluep);
+  YYUSE (yyvaluep);
   if (!yymsg)
     yymsg = "Deleting";
   YY_SYMBOL_PRINT (yymsg, yykind, yyvaluep, yylocationp);
 
   YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
-  YY_USE (yykind);
+  YYUSE (yykind);
   YY_IGNORE_MAYBE_UNINITIALIZED_END
 }
 
@@ -1359,373 +1347,373 @@ yyreduce:
   case 4: /* command: NAME opt_name opt_base  */
 #line 53 "defparse.y"
                                        { def_name ((yyvsp[-1].id), (yyvsp[0].number)); }
-#line 1363 "defparse.c"
+#line 1351 "defparse.c"
     break;
 
   case 5: /* command: LIBRARY opt_name opt_base option_list  */
 #line 54 "defparse.y"
                                                       { def_library ((yyvsp[-2].id), (yyvsp[-1].number)); }
-#line 1369 "defparse.c"
+#line 1357 "defparse.c"
     break;
 
   case 7: /* command: DESCRIPTION ID  */
 #line 56 "defparse.y"
                                { def_description ((yyvsp[0].id));}
-#line 1375 "defparse.c"
+#line 1363 "defparse.c"
     break;
 
   case 8: /* command: STACKSIZE NUMBER opt_number  */
 #line 57 "defparse.y"
                                             { def_stacksize ((yyvsp[-1].number), (yyvsp[0].number));}
-#line 1381 "defparse.c"
+#line 1369 "defparse.c"
     break;
 
   case 9: /* command: HEAPSIZE NUMBER opt_number  */
 #line 58 "defparse.y"
                                            { def_heapsize ((yyvsp[-1].number), (yyvsp[0].number));}
-#line 1387 "defparse.c"
+#line 1375 "defparse.c"
     break;
 
   case 10: /* command: CODE attr_list  */
 #line 59 "defparse.y"
                                { def_code ((yyvsp[0].number));}
-#line 1393 "defparse.c"
+#line 1381 "defparse.c"
     break;
 
   case 11: /* command: DATA attr_list  */
 #line 60 "defparse.y"
                                 { def_data ((yyvsp[0].number));}
-#line 1399 "defparse.c"
+#line 1387 "defparse.c"
     break;
 
   case 14: /* command: VERSIONK NUMBER  */
 #line 63 "defparse.y"
                                 { def_version ((yyvsp[0].number),0);}
-#line 1405 "defparse.c"
+#line 1393 "defparse.c"
     break;
 
   case 15: /* command: VERSIONK NUMBER '.' NUMBER  */
 #line 64 "defparse.y"
                                            { def_version ((yyvsp[-2].number),(yyvsp[0].number));}
-#line 1411 "defparse.c"
+#line 1399 "defparse.c"
     break;
 
   case 18: /* expline: ID opt_equal_name opt_ordinal opt_NONAME opt_CONSTANT opt_DATA opt_PRIVATE opt_import_name  */
 #line 76 "defparse.y"
                         { def_exports ((yyvsp[-7].id), (yyvsp[-6].id), (yyvsp[-5].number), (yyvsp[-4].number), (yyvsp[-3].number), (yyvsp[-2].number), (yyvsp[-1].number), (yyvsp[0].id));}
-#line 1417 "defparse.c"
+#line 1405 "defparse.c"
     break;
 
   case 21: /* impline: ID '=' ID '.' ID '.' ID opt_import_name  */
 #line 85 "defparse.y"
                  { def_import ((yyvsp[-7].id),(yyvsp[-5].id),(yyvsp[-3].id),(yyvsp[-1].id), 0, (yyvsp[0].id)); }
-#line 1423 "defparse.c"
+#line 1411 "defparse.c"
     break;
 
   case 22: /* impline: ID '=' ID '.' ID '.' NUMBER opt_import_name  */
 #line 87 "defparse.y"
                  { def_import ((yyvsp[-7].id),(yyvsp[-5].id),(yyvsp[-3].id), 0,(yyvsp[-1].number), (yyvsp[0].id)); }
-#line 1429 "defparse.c"
+#line 1417 "defparse.c"
     break;
 
   case 23: /* impline: ID '=' ID '.' ID opt_import_name  */
 #line 89 "defparse.y"
                  { def_import ((yyvsp[-5].id),(yyvsp[-3].id), 0,(yyvsp[-1].id), 0, (yyvsp[0].id)); }
-#line 1435 "defparse.c"
+#line 1423 "defparse.c"
     break;
 
   case 24: /* impline: ID '=' ID '.' NUMBER opt_import_name  */
 #line 91 "defparse.y"
                  { def_import ((yyvsp[-5].id),(yyvsp[-3].id), 0, 0,(yyvsp[-1].number), (yyvsp[0].id)); }
-#line 1441 "defparse.c"
+#line 1429 "defparse.c"
     break;
 
   case 25: /* impline: ID '.' ID '.' ID opt_import_name  */
 #line 93 "defparse.y"
                  { def_import ( 0,(yyvsp[-5].id),(yyvsp[-3].id),(yyvsp[-1].id), 0, (yyvsp[0].id)); }
-#line 1447 "defparse.c"
+#line 1435 "defparse.c"
     break;
 
   case 26: /* impline: ID '.' ID '.' NUMBER opt_import_name  */
 #line 95 "defparse.y"
                  { def_import ( 0,(yyvsp[-5].id),(yyvsp[-3].id), 0,(yyvsp[-1].number), (yyvsp[0].id)); }
-#line 1453 "defparse.c"
+#line 1441 "defparse.c"
     break;
 
   case 27: /* impline: ID '.' ID opt_import_name  */
 #line 97 "defparse.y"
                  { def_import ( 0,(yyvsp[-3].id), 0,(yyvsp[-1].id), 0, (yyvsp[0].id)); }
-#line 1459 "defparse.c"
+#line 1447 "defparse.c"
     break;
 
   case 28: /* impline: ID '.' NUMBER opt_import_name  */
 #line 99 "defparse.y"
                  { def_import ( 0,(yyvsp[-3].id), 0, 0,(yyvsp[-1].number), (yyvsp[0].id)); }
-#line 1465 "defparse.c"
+#line 1453 "defparse.c"
     break;
 
   case 31: /* secline: ID attr_list  */
 #line 108 "defparse.y"
                      { def_section ((yyvsp[-1].id),(yyvsp[0].number));}
-#line 1471 "defparse.c"
+#line 1459 "defparse.c"
     break;
 
   case 36: /* opt_number: ',' NUMBER  */
 #line 120 "defparse.y"
                        { (yyval.number)=(yyvsp[0].number);}
-#line 1477 "defparse.c"
+#line 1465 "defparse.c"
     break;
 
   case 37: /* opt_number: %empty  */
 #line 121 "defparse.y"
                    { (yyval.number)=-1;}
-#line 1483 "defparse.c"
+#line 1471 "defparse.c"
     break;
 
   case 38: /* attr: READ  */
 #line 125 "defparse.y"
                      { (yyval.number) = 1; }
-#line 1489 "defparse.c"
+#line 1477 "defparse.c"
     break;
 
   case 39: /* attr: WRITE  */
 #line 126 "defparse.y"
                       { (yyval.number) = 2; }
-#line 1495 "defparse.c"
+#line 1483 "defparse.c"
     break;
 
   case 40: /* attr: EXECUTE  */
 #line 127 "defparse.y"
                         { (yyval.number) = 4; }
-#line 1501 "defparse.c"
+#line 1489 "defparse.c"
     break;
 
   case 41: /* attr: SHARED  */
 #line 128 "defparse.y"
                        { (yyval.number) = 8; }
-#line 1507 "defparse.c"
+#line 1495 "defparse.c"
     break;
 
   case 42: /* attr: NONSHARED  */
 #line 129 "defparse.y"
                           { (yyval.number) = 0; }
-#line 1513 "defparse.c"
+#line 1501 "defparse.c"
     break;
 
   case 43: /* attr: SINGLE  */
 #line 130 "defparse.y"
                        { (yyval.number) = 0; }
-#line 1519 "defparse.c"
+#line 1507 "defparse.c"
     break;
 
   case 44: /* attr: MULTIPLE  */
 #line 131 "defparse.y"
                          { (yyval.number) = 0; }
-#line 1525 "defparse.c"
+#line 1513 "defparse.c"
     break;
 
   case 45: /* opt_CONSTANT: CONSTANT  */
 #line 135 "defparse.y"
                          {(yyval.number)=1;}
-#line 1531 "defparse.c"
+#line 1519 "defparse.c"
     break;
 
   case 46: /* opt_CONSTANT: %empty  */
 #line 136 "defparse.y"
                          {(yyval.number)=0;}
-#line 1537 "defparse.c"
+#line 1525 "defparse.c"
     break;
 
   case 47: /* opt_NONAME: NONAME  */
 #line 140 "defparse.y"
                        {(yyval.number)=1;}
-#line 1543 "defparse.c"
+#line 1531 "defparse.c"
     break;
 
   case 48: /* opt_NONAME: %empty  */
 #line 141 "defparse.y"
                          {(yyval.number)=0;}
-#line 1549 "defparse.c"
+#line 1537 "defparse.c"
     break;
 
   case 49: /* opt_DATA: DATA  */
 #line 145 "defparse.y"
                      { (yyval.number) = 1; }
-#line 1555 "defparse.c"
+#line 1543 "defparse.c"
     break;
 
   case 50: /* opt_DATA: %empty  */
 #line 146 "defparse.y"
                      { (yyval.number) = 0; }
-#line 1561 "defparse.c"
+#line 1549 "defparse.c"
     break;
 
   case 51: /* opt_PRIVATE: PRIVATE  */
 #line 150 "defparse.y"
                         { (yyval.number) = 1; }
-#line 1567 "defparse.c"
+#line 1555 "defparse.c"
     break;
 
   case 52: /* opt_PRIVATE: %empty  */
 #line 151 "defparse.y"
                         { (yyval.number) = 0; }
-#line 1573 "defparse.c"
+#line 1561 "defparse.c"
     break;
 
   case 53: /* keyword_as_name: NAME  */
 #line 154 "defparse.y"
                       { (yyval.id_const) = "NAME"; }
-#line 1579 "defparse.c"
+#line 1567 "defparse.c"
     break;
 
   case 54: /* keyword_as_name: DESCRIPTION  */
 #line 159 "defparse.y"
                       { (yyval.id_const) = "DESCRIPTION"; }
-#line 1585 "defparse.c"
+#line 1573 "defparse.c"
     break;
 
   case 55: /* keyword_as_name: STACKSIZE  */
 #line 160 "defparse.y"
                     { (yyval.id_const) = "STACKSIZE"; }
-#line 1591 "defparse.c"
+#line 1579 "defparse.c"
     break;
 
   case 56: /* keyword_as_name: HEAPSIZE  */
 #line 161 "defparse.y"
                    { (yyval.id_const) = "HEAPSIZE"; }
-#line 1597 "defparse.c"
+#line 1585 "defparse.c"
     break;
 
   case 57: /* keyword_as_name: CODE  */
 #line 162 "defparse.y"
                { (yyval.id_const) = "CODE"; }
-#line 1603 "defparse.c"
+#line 1591 "defparse.c"
     break;
 
   case 58: /* keyword_as_name: DATA  */
 #line 163 "defparse.y"
                { (yyval.id_const) = "DATA"; }
-#line 1609 "defparse.c"
+#line 1597 "defparse.c"
     break;
 
   case 59: /* keyword_as_name: SECTIONS  */
 #line 164 "defparse.y"
                    { (yyval.id_const) = "SECTIONS"; }
-#line 1615 "defparse.c"
+#line 1603 "defparse.c"
     break;
 
   case 60: /* keyword_as_name: EXPORTS  */
 #line 165 "defparse.y"
                   { (yyval.id_const) = "EXPORTS"; }
-#line 1621 "defparse.c"
+#line 1609 "defparse.c"
     break;
 
   case 61: /* keyword_as_name: IMPORTS  */
 #line 166 "defparse.y"
                   { (yyval.id_const) = "IMPORTS"; }
-#line 1627 "defparse.c"
+#line 1615 "defparse.c"
     break;
 
   case 62: /* keyword_as_name: VERSIONK  */
 #line 167 "defparse.y"
                    { (yyval.id_const) = "VERSION"; }
-#line 1633 "defparse.c"
+#line 1621 "defparse.c"
     break;
 
   case 63: /* keyword_as_name: BASE  */
 #line 168 "defparse.y"
                { (yyval.id_const) = "BASE"; }
-#line 1639 "defparse.c"
+#line 1627 "defparse.c"
     break;
 
   case 64: /* keyword_as_name: CONSTANT  */
 #line 169 "defparse.y"
                    { (yyval.id_const) = "CONSTANT"; }
-#line 1645 "defparse.c"
+#line 1633 "defparse.c"
     break;
 
   case 65: /* keyword_as_name: NONAME  */
 #line 170 "defparse.y"
                  { (yyval.id_const) = "NONAME"; }
-#line 1651 "defparse.c"
+#line 1639 "defparse.c"
     break;
 
   case 66: /* keyword_as_name: PRIVATE  */
 #line 171 "defparse.y"
                   { (yyval.id_const) = "PRIVATE"; }
-#line 1657 "defparse.c"
+#line 1645 "defparse.c"
     break;
 
   case 67: /* keyword_as_name: READ  */
 #line 172 "defparse.y"
                { (yyval.id_const) = "READ"; }
-#line 1663 "defparse.c"
+#line 1651 "defparse.c"
     break;
 
   case 68: /* keyword_as_name: WRITE  */
 #line 173 "defparse.y"
                 { (yyval.id_const) = "WRITE"; }
-#line 1669 "defparse.c"
+#line 1657 "defparse.c"
     break;
 
   case 69: /* keyword_as_name: EXECUTE  */
 #line 174 "defparse.y"
                   { (yyval.id_const) = "EXECUTE"; }
-#line 1675 "defparse.c"
+#line 1663 "defparse.c"
     break;
 
   case 70: /* keyword_as_name: SHARED  */
 #line 175 "defparse.y"
                  { (yyval.id_const) = "SHARED"; }
-#line 1681 "defparse.c"
+#line 1669 "defparse.c"
     break;
 
   case 71: /* keyword_as_name: NONSHARED  */
 #line 176 "defparse.y"
                     { (yyval.id_const) = "NONSHARED"; }
-#line 1687 "defparse.c"
+#line 1675 "defparse.c"
     break;
 
   case 72: /* keyword_as_name: SINGLE  */
 #line 177 "defparse.y"
                  { (yyval.id_const) = "SINGLE"; }
-#line 1693 "defparse.c"
+#line 1681 "defparse.c"
     break;
 
   case 73: /* keyword_as_name: MULTIPLE  */
 #line 178 "defparse.y"
                    { (yyval.id_const) = "MULTIPLE"; }
-#line 1699 "defparse.c"
+#line 1687 "defparse.c"
     break;
 
   case 74: /* keyword_as_name: INITINSTANCE  */
 #line 179 "defparse.y"
                        { (yyval.id_const) = "INITINSTANCE"; }
-#line 1705 "defparse.c"
+#line 1693 "defparse.c"
     break;
 
   case 75: /* keyword_as_name: INITGLOBAL  */
 #line 180 "defparse.y"
                      { (yyval.id_const) = "INITGLOBAL"; }
-#line 1711 "defparse.c"
+#line 1699 "defparse.c"
     break;
 
   case 76: /* keyword_as_name: TERMINSTANCE  */
 #line 181 "defparse.y"
                        { (yyval.id_const) = "TERMINSTANCE"; }
-#line 1717 "defparse.c"
+#line 1705 "defparse.c"
     break;
 
   case 77: /* keyword_as_name: TERMGLOBAL  */
 #line 182 "defparse.y"
                      { (yyval.id_const) = "TERMGLOBAL"; }
-#line 1723 "defparse.c"
+#line 1711 "defparse.c"
     break;
 
   case 78: /* opt_name2: ID  */
 #line 185 "defparse.y"
               { (yyval.id) = (yyvsp[0].id); }
-#line 1729 "defparse.c"
+#line 1717 "defparse.c"
     break;
 
   case 79: /* opt_name2: '.' keyword_as_name  */
@@ -1735,7 +1723,7 @@ yyreduce:
 	    sprintf (name, ".%s", (yyvsp[0].id_const));
 	    (yyval.id) = name;
 	  }
-#line 1739 "defparse.c"
+#line 1727 "defparse.c"
     break;
 
   case 80: /* opt_name2: '.' opt_name2  */
@@ -1745,7 +1733,7 @@ yyreduce:
 	    sprintf (name, ".%s", (yyvsp[0].id));
 	    (yyval.id) = name;
 	  }
-#line 1749 "defparse.c"
+#line 1737 "defparse.c"
     break;
 
   case 81: /* opt_name2: keyword_as_name '.' opt_name2  */
@@ -1755,7 +1743,7 @@ yyreduce:
 	    sprintf (name, "%s.%s", (yyvsp[-2].id_const), (yyvsp[0].id));
 	    (yyval.id) = name;
 	  }
-#line 1759 "defparse.c"
+#line 1747 "defparse.c"
     break;
 
   case 82: /* opt_name2: ID '.' opt_name2  */
@@ -1765,71 +1753,71 @@ yyreduce:
 	    sprintf (name, "%s.%s", (yyvsp[-2].id), (yyvsp[0].id));
 	    (yyval.id) = name;
 	  }
-#line 1769 "defparse.c"
+#line 1757 "defparse.c"
     break;
 
   case 83: /* opt_name: opt_name2  */
 #line 211 "defparse.y"
                     { (yyval.id) =(yyvsp[0].id); }
-#line 1775 "defparse.c"
+#line 1763 "defparse.c"
     break;
 
   case 84: /* opt_name: %empty  */
 #line 212 "defparse.y"
                         { (yyval.id)=""; }
-#line 1781 "defparse.c"
+#line 1769 "defparse.c"
     break;
 
   case 85: /* opt_ordinal: '@' NUMBER  */
 #line 216 "defparse.y"
                          { (yyval.number)=(yyvsp[0].number);}
-#line 1787 "defparse.c"
+#line 1775 "defparse.c"
     break;
 
   case 86: /* opt_ordinal: %empty  */
 #line 217 "defparse.y"
                          { (yyval.number)=-1;}
-#line 1793 "defparse.c"
+#line 1781 "defparse.c"
     break;
 
   case 87: /* opt_import_name: EQUAL opt_name2  */
 #line 221 "defparse.y"
                                 { (yyval.id) = (yyvsp[0].id); }
-#line 1799 "defparse.c"
+#line 1787 "defparse.c"
     break;
 
   case 88: /* opt_import_name: %empty  */
 #line 222 "defparse.y"
                         { (yyval.id) = 0; }
-#line 1805 "defparse.c"
+#line 1793 "defparse.c"
     break;
 
   case 89: /* opt_equal_name: '=' opt_name2  */
 #line 226 "defparse.y"
                         { (yyval.id) = (yyvsp[0].id); }
-#line 1811 "defparse.c"
+#line 1799 "defparse.c"
     break;
 
   case 90: /* opt_equal_name: %empty  */
 #line 227 "defparse.y"
                         { (yyval.id) =  0; }
-#line 1817 "defparse.c"
+#line 1805 "defparse.c"
     break;
 
   case 91: /* opt_base: BASE '=' NUMBER  */
 #line 230 "defparse.y"
                                 { (yyval.number)= (yyvsp[0].number);}
-#line 1823 "defparse.c"
+#line 1811 "defparse.c"
     break;
 
   case 92: /* opt_base: %empty  */
 #line 231 "defparse.y"
                 { (yyval.number)=-1;}
-#line 1829 "defparse.c"
+#line 1817 "defparse.c"
     break;
 
 
-#line 1833 "defparse.c"
+#line 1821 "defparse.c"
 
       default: break;
     }
