@@ -1,8 +1,8 @@
-/* A Bison parser, made by GNU Bison 3.7.6.  */
+/* A Bison parser, made by GNU Bison 3.7.4.  */
 
 /* Bison implementation for Yacc-like parsers in C
 
-   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2021 Free Software Foundation,
+   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2020 Free Software Foundation,
    Inc.
 
    This program is free software: you can redistribute it and/or modify
@@ -16,7 +16,7 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
 /* As a special exception, you may create a larger work that contains
    part or all of the Bison parser skeleton and distribute that work
@@ -46,10 +46,10 @@
    USER NAME SPACE" below.  */
 
 /* Identify Bison output, and Bison version.  */
-#define YYBISON 30706
+#define YYBISON 30704
 
 /* Bison version string.  */
-#define YYBISON_VERSION "3.7.6"
+#define YYBISON_VERSION "3.7.4"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -83,7 +83,7 @@ static int rdepth;
 static char *names[] = {" ","[n]","[n][m]"};
 static char *pnames[]= {"","*","**"};
 
-static int yyerror (char *s);
+static void yyerror (const char *s);
 extern int yylex (void);
 
 #line 90 "sysinfo.c"
@@ -251,18 +251,6 @@ typedef int_least16_t yytype_int16;
 typedef short yytype_int16;
 #endif
 
-/* Work around bug in HP-UX 11.23, which defines these macros
-   incorrectly for preprocessor constants.  This workaround can likely
-   be removed in 2023, as HPE has promised support for HP-UX 11.23
-   (aka HP-UX 11i v2) only through the end of 2022; see Table 2 of
-   <https://h20195.www2.hpe.com/V2/getpdf.aspx/4AA4-7673ENW.pdf>.  */
-#ifdef __hpux
-# undef UINT_LEAST8_MAX
-# undef UINT_LEAST16_MAX
-# define UINT_LEAST8_MAX 255
-# define UINT_LEAST16_MAX 65535
-#endif
-
 #if defined __UINT_LEAST8_MAX__ && __UINT_LEAST8_MAX__ <= __INT_MAX__
 typedef __UINT_LEAST8_TYPE__ yytype_uint8;
 #elif (!defined __UINT_LEAST8_MAX__ && defined YY_STDINT_H \
@@ -360,9 +348,9 @@ typedef int yy_state_fast_t;
 
 /* Suppress unused-variable warnings by "using" E.  */
 #if ! defined lint || defined __GNUC__
-# define YY_USE(E) ((void) (E))
+# define YYUSE(E) ((void) (E))
 #else
-# define YY_USE(E) /* empty */
+# define YYUSE(E) /* empty */
 #endif
 
 #if defined __GNUC__ && ! defined __ICC && 407 <= __GNUC__ * 100 + __GNUC_MINOR__
@@ -675,7 +663,7 @@ static const yytype_int8 yypgoto[] =
   /* YYDEFGOTO[NTERM-NUM].  */
 static const yytype_int8 yydefgoto[] =
 {
-       0,     1,     2,     5,     6,    10,    12,    13,    29,    14,
+      -1,     1,     2,     5,     6,    10,    12,    13,    29,    14,
       28,    15,    44,    32,    19,    36,    42,    47,    48
 };
 
@@ -802,7 +790,7 @@ yy_symbol_value_print (FILE *yyo,
                        yysymbol_kind_t yykind, YYSTYPE const * const yyvaluep)
 {
   FILE *yyoutput = yyo;
-  YY_USE (yyoutput);
+  YYUSE (yyoutput);
   if (!yyvaluep)
     return;
 # ifdef YYPRINT
@@ -810,7 +798,7 @@ yy_symbol_value_print (FILE *yyo,
     YYPRINT (yyo, yytoknum[yykind], *yyvaluep);
 # endif
   YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
-  YY_USE (yykind);
+  YYUSE (yykind);
   YY_IGNORE_MAYBE_UNINITIALIZED_END
 }
 
@@ -924,13 +912,13 @@ static void
 yydestruct (const char *yymsg,
             yysymbol_kind_t yykind, YYSTYPE *yyvaluep)
 {
-  YY_USE (yyvaluep);
+  YYUSE (yyvaluep);
   if (!yymsg)
     yymsg = "Deleting";
   YY_SYMBOL_PRINT (yymsg, yykind, yyvaluep, yylocationp);
 
   YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
-  YY_USE (yykind);
+  YYUSE (yykind);
   YY_IGNORE_MAYBE_UNINITIALIZED_END
 }
 
@@ -1214,7 +1202,7 @@ yyreduce:
       break;
     }
  }
-#line 1218 "sysinfo.c"
+#line 1206 "sysinfo.c"
     break;
 
   case 3: /* top: $@1 it_list  */
@@ -1231,7 +1219,7 @@ yyreduce:
     break;
   }
 }
-#line 1235 "sysinfo.c"
+#line 1223 "sysinfo.c"
     break;
 
   case 6: /* $@2: %empty  */
@@ -1285,7 +1273,7 @@ yyreduce:
 	  }
 
       }
-#line 1289 "sysinfo.c"
+#line 1277 "sysinfo.c"
     break;
 
   case 7: /* it: '(' NAME NUMBER $@2 it_field_list ')'  */
@@ -1306,7 +1294,7 @@ yyreduce:
 
   free (it);
 }
-#line 1310 "sysinfo.c"
+#line 1298 "sysinfo.c"
     break;
 
   case 12: /* $@3: %empty  */
@@ -1339,7 +1327,7 @@ yyreduce:
 	  oldrepeat = repeat;
          repeat = (yyvsp[0].s);
 	}
-#line 1343 "sysinfo.c"
+#line 1331 "sysinfo.c"
     break;
 
   case 13: /* repeat_it_field: '(' REPEAT NAME $@3 it_field_list ')'  */
@@ -1359,7 +1347,7 @@ yyreduce:
 	  printf("\t}}\n");
 	}
 	}
-#line 1363 "sysinfo.c"
+#line 1351 "sysinfo.c"
     break;
 
   case 14: /* $@4: %empty  */
@@ -1377,7 +1365,7 @@ yyreduce:
 
 	  free ((yyvsp[0].s));
 	}
-#line 1381 "sysinfo.c"
+#line 1369 "sysinfo.c"
     break;
 
   case 15: /* cond_it_field: '(' COND NAME $@4 it_field_list ')'  */
@@ -1392,13 +1380,13 @@ yyreduce:
 	  printf("\t}\n");
 	}
 	}
-#line 1396 "sysinfo.c"
+#line 1384 "sysinfo.c"
     break;
 
   case 16: /* $@5: %empty  */
 #line 257 "sysinfo.y"
         {name = (yyvsp[0].s); }
-#line 1402 "sysinfo.c"
+#line 1390 "sysinfo.c"
     break;
 
   case 17: /* it_field: '(' attr_desc '(' attr_type attr_size ')' attr_id $@5 enums ')'  */
@@ -1506,43 +1494,43 @@ char *ptr = pnames[rdepth];
 	  free (desc);
 	  free (id);
 	}
-#line 1510 "sysinfo.c"
+#line 1498 "sysinfo.c"
     break;
 
   case 18: /* attr_type: TYPE  */
 #line 367 "sysinfo.y"
               { (yyval.s) = (yyvsp[0].s); }
-#line 1516 "sysinfo.c"
+#line 1504 "sysinfo.c"
     break;
 
   case 19: /* attr_type: %empty  */
 #line 368 "sysinfo.y"
            { (yyval.s) = "INT";}
-#line 1522 "sysinfo.c"
+#line 1510 "sysinfo.c"
     break;
 
   case 20: /* attr_desc: '(' NAME ')'  */
 #line 373 "sysinfo.y"
         { (yyval.s) = (yyvsp[-1].s); }
-#line 1528 "sysinfo.c"
+#line 1516 "sysinfo.c"
     break;
 
   case 21: /* attr_size: NUMBER UNIT  */
 #line 378 "sysinfo.y"
         { (yyval.i) = (yyvsp[-1].i) * (yyvsp[0].i); }
-#line 1534 "sysinfo.c"
+#line 1522 "sysinfo.c"
     break;
 
   case 22: /* attr_id: '(' NAME ')'  */
 #line 383 "sysinfo.y"
                                 { (yyval.s) = (yyvsp[-1].s); }
-#line 1540 "sysinfo.c"
+#line 1528 "sysinfo.c"
     break;
 
   case 23: /* attr_id: %empty  */
 #line 384 "sysinfo.y"
                 { (yyval.s) = strdup ("dummy");}
-#line 1546 "sysinfo.c"
+#line 1534 "sysinfo.c"
     break;
 
   case 27: /* enum_list: enum_list '(' NAME NAME ')'  */
@@ -1560,11 +1548,11 @@ char *ptr = pnames[rdepth];
 	  free ((yyvsp[-2].s));
 	  free ((yyvsp[-1].s));
 	}
-#line 1564 "sysinfo.c"
+#line 1552 "sysinfo.c"
     break;
 
 
-#line 1568 "sysinfo.c"
+#line 1556 "sysinfo.c"
 
       default: break;
     }
@@ -1786,9 +1774,8 @@ if (writecode == 'd')
 return 0;
 }
 
-static int
-yyerror (char *s)
+static void
+yyerror (const char *s)
 {
   fprintf(stderr, "%s\n" , s);
-  return 0;
 }
