@@ -1,5 +1,5 @@
 /* tc-bpf.h -- Header file for tc-ebpf.c.
-   Copyright (C) 2019-2020 Free Software Foundation, Inc.
+   Copyright (C) 2019-2022 Free Software Foundation, Inc.
    Contributed by Oracle, Inc.
 
    This file is part of GAS, the GNU Assembler.
@@ -48,3 +48,6 @@
 /* Values passed to md_apply_fix don't include the symbol value.  */
 #define MD_APPLY_SYM_VALUE(FIX) 0
 
+/* The Linux kernel verifier expects NOPs to be encoded in this way;
+   a jump to offset 0 means jump to the next instruction.  */
+#define md_single_noop_insn "ja 0"
