@@ -1,5 +1,5 @@
 /* tc-metag.h -- Header file for tc-metag.c.
-   Copyright (C) 2013-2020 Free Software Foundation, Inc.
+   Copyright (C) 2013-2022 Free Software Foundation, Inc.
    Contributed by Imagination Technologies Ltd.
 
    This file is part of GAS, the GNU Assembler.
@@ -42,7 +42,7 @@
 #define MD_APPLY_SYM_VALUE(FIX) 0
 
 #define tc_fix_adjustable(FIX) metag_fix_adjustable (FIX)
-extern bfd_boolean metag_fix_adjustable (struct fix *);
+extern bool metag_fix_adjustable (struct fix *);
 
 #define TC_FORCE_RELOCATION(fix) metag_force_relocation (fix)
 extern int metag_force_relocation (struct fix *);
@@ -51,7 +51,6 @@ extern int metag_force_relocation (struct fix *);
 
 /* Call md_pcrel_from_section(), not md_pcrel_from().  */
 #define MD_PCREL_FROM_SECTION(FIX, SEC) md_pcrel_from_section (FIX, SEC)
-extern long md_pcrel_from_section (struct fix *, segT);
 
 #define HANDLE_ALIGN(fragp) metag_handle_align (fragp)
 extern void metag_handle_align (struct frag *);
