@@ -1,5 +1,5 @@
 /* tc-tilepro.c -- Assemble for a TILEPro chip.
-   Copyright (C) 2011-2021 Free Software Foundation, Inc.
+   Copyright (C) 2011-2022 Free Software Foundation, Inc.
 
    This file is part of GAS, the GNU Assembler.
 
@@ -778,7 +778,7 @@ tilepro_flush_bundle (void)
 	  /* Make sure all instructions can be bundled with other
 	     instructions.  */
 	  const struct tilepro_opcode *cannot_bundle = NULL;
-	  bfd_boolean seen_non_nop = FALSE;
+	  bool seen_non_nop = false;
 
 	  for (j = 0; j < current_bundle_index; j++)
 	    {
@@ -789,7 +789,7 @@ tilepro_flush_bundle (void)
 	      else if (op->mnemonic != TILEPRO_OPC_NOP
 		       && op->mnemonic != TILEPRO_OPC_INFO
 		       && op->mnemonic != TILEPRO_OPC_INFOL)
-		seen_non_nop = TRUE;
+		seen_non_nop = true;
 	    }
 
 	  if (cannot_bundle != NULL && seen_non_nop)
@@ -1334,7 +1334,7 @@ md_apply_fix (fixS *fixP, valueT * valP, segT seg ATTRIBUTE_UNUSED)
   if (fixP->fx_subsy != (symbolS *) NULL)
     {
       /* We can't actually support subtracting a symbol.  */
-      as_bad_where (fixP->fx_file, fixP->fx_line, _("expression too complex"));
+      as_bad_subtract (fixP);
     }
 
   /* Correct relocation types for pc-relativeness.  */
