@@ -1,8 +1,8 @@
-/* A Bison parser, made by GNU Bison 3.7.6.  */
+/* A Bison parser, made by GNU Bison 3.7.4.  */
 
 /* Bison implementation for Yacc-like parsers in C
 
-   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2021 Free Software Foundation,
+   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2020 Free Software Foundation,
    Inc.
 
    This program is free software: you can redistribute it and/or modify
@@ -16,7 +16,7 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
 /* As a special exception, you may create a larger work that contains
    part or all of the Bison parser skeleton and distribute that work
@@ -46,10 +46,10 @@
    USER NAME SPACE" below.  */
 
 /* Identify Bison output, and Bison version.  */
-#define YYBISON 30706
+#define YYBISON 30704
 
 /* Bison version string.  */
-#define YYBISON_VERSION "3.7.6"
+#define YYBISON_VERSION "3.7.4"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -324,7 +324,7 @@ FIXME! hex is ambiguous with any digit
 
 static int sbit, ebit;
 static struct itbl_entry *insn=0;
-static int yyerror (const char *);
+static void yyerror (const char *);
 
 
 #line 331 "itbl-parse.c"
@@ -508,18 +508,6 @@ typedef int_least16_t yytype_int16;
 typedef short yytype_int16;
 #endif
 
-/* Work around bug in HP-UX 11.23, which defines these macros
-   incorrectly for preprocessor constants.  This workaround can likely
-   be removed in 2023, as HPE has promised support for HP-UX 11.23
-   (aka HP-UX 11i v2) only through the end of 2022; see Table 2 of
-   <https://h20195.www2.hpe.com/V2/getpdf.aspx/4AA4-7673ENW.pdf>.  */
-#ifdef __hpux
-# undef UINT_LEAST8_MAX
-# undef UINT_LEAST16_MAX
-# define UINT_LEAST8_MAX 255
-# define UINT_LEAST16_MAX 65535
-#endif
-
 #if defined __UINT_LEAST8_MAX__ && __UINT_LEAST8_MAX__ <= __INT_MAX__
 typedef __UINT_LEAST8_TYPE__ yytype_uint8;
 #elif (!defined __UINT_LEAST8_MAX__ && defined YY_STDINT_H \
@@ -617,9 +605,9 @@ typedef int yy_state_fast_t;
 
 /* Suppress unused-variable warnings by "using" E.  */
 #if ! defined lint || defined __GNUC__
-# define YY_USE(E) ((void) (E))
+# define YYUSE(E) ((void) (E))
 #else
-# define YY_USE(E) /* empty */
+# define YYUSE(E) /* empty */
 #endif
 
 #if defined __GNUC__ && ! defined __ICC && 407 <= __GNUC__ * 100 + __GNUC_MINOR__
@@ -932,7 +920,7 @@ static const yytype_int8 yypgoto[] =
   /* YYDEFGOTO[NTERM-NUM].  */
 static const yytype_int8 yydefgoto[] =
 {
-       0,     4,     5,     6,    32,    39,    40,    41,    31,    27,
+      -1,     4,     5,     6,    32,    39,    40,    41,    31,    27,
       23,     7,    42,    17,    20
 };
 
@@ -1061,7 +1049,7 @@ yy_symbol_value_print (FILE *yyo,
                        yysymbol_kind_t yykind, YYSTYPE const * const yyvaluep)
 {
   FILE *yyoutput = yyo;
-  YY_USE (yyoutput);
+  YYUSE (yyoutput);
   if (!yyvaluep)
     return;
 # ifdef YYPRINT
@@ -1069,7 +1057,7 @@ yy_symbol_value_print (FILE *yyo,
     YYPRINT (yyo, yytoknum[yykind], *yyvaluep);
 # endif
   YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
-  YY_USE (yykind);
+  YYUSE (yykind);
   YY_IGNORE_MAYBE_UNINITIALIZED_END
 }
 
@@ -1183,13 +1171,13 @@ static void
 yydestruct (const char *yymsg,
             yysymbol_kind_t yykind, YYSTYPE *yyvaluep)
 {
-  YY_USE (yyvaluep);
+  YYUSE (yyvaluep);
   if (!yymsg)
     yymsg = "Deleting";
   YY_SYMBOL_PRINT (yymsg, yykind, yyvaluep, yylocationp);
 
   YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
-  YY_USE (yykind);
+  YYUSE (yykind);
   YY_IGNORE_MAYBE_UNINITIALIZED_END
 }
 
@@ -1456,7 +1444,7 @@ yyreduce:
 	    	    insntbl_line, (yyvsp[-4].num), (yyvsp[-3].num), (yyvsp[-2].str), (yyvsp[-1].val)));
 	    itbl_add_reg ((yyvsp[-4].num), (yyvsp[-3].num), (yyvsp[-2].str), (yyvsp[-1].val));
 	  }
-#line 1460 "itbl-parse.c"
+#line 1448 "itbl-parse.c"
     break;
 
   case 6: /* $@1: %empty  */
@@ -1467,13 +1455,13 @@ yyreduce:
 	    DBG ((" sbit=%d ebit=%d flags=0x%x\n", sbit, ebit, (yyvsp[0].val)));
 	    insn=itbl_add_insn ((yyvsp[-5].num), (yyvsp[-3].str), (yyvsp[-2].val), sbit, ebit, (yyvsp[0].val));
 	  }
-#line 1471 "itbl-parse.c"
+#line 1459 "itbl-parse.c"
     break;
 
   case 7: /* entry: pnum INSN name value range flags $@1 fieldspecs NL  */
 #line 322 "./itbl-parse.y"
           {}
-#line 1477 "itbl-parse.c"
+#line 1465 "itbl-parse.c"
     break;
 
   case 13: /* ftype: regtype  */
@@ -1482,7 +1470,7 @@ yyreduce:
 	    DBGL2 (("ftype\n"));
 	    (yyval.num) = (yyvsp[0].num);
 	  }
-#line 1486 "itbl-parse.c"
+#line 1474 "itbl-parse.c"
     break;
 
   case 14: /* ftype: ADDR  */
@@ -1491,7 +1479,7 @@ yyreduce:
 	    DBGL2 (("addr\n"));
 	    (yyval.num) = ADDR;
 	  }
-#line 1495 "itbl-parse.c"
+#line 1483 "itbl-parse.c"
     break;
 
   case 15: /* ftype: IMMED  */
@@ -1500,7 +1488,7 @@ yyreduce:
 	    DBGL2 (("immed\n"));
 	    (yyval.num) = IMMED;
 	  }
-#line 1504 "itbl-parse.c"
+#line 1492 "itbl-parse.c"
     break;
 
   case 16: /* fieldspec: ftype range flags  */
@@ -1510,7 +1498,7 @@ yyreduce:
 	    	    insntbl_line, (yyvsp[-2].num), sbit, ebit, (yyvsp[0].val)));
 	    itbl_add_operand (insn, (yyvsp[-2].num), sbit, ebit, (yyvsp[0].val));
 	  }
-#line 1514 "itbl-parse.c"
+#line 1502 "itbl-parse.c"
     break;
 
   case 17: /* flagexpr: NUM '|' flagexpr  */
@@ -1518,7 +1506,7 @@ yyreduce:
           {
 	    (yyval.val) = (yyvsp[-2].num) | (yyvsp[0].val);
 	  }
-#line 1522 "itbl-parse.c"
+#line 1510 "itbl-parse.c"
     break;
 
   case 18: /* flagexpr: '[' flagexpr ']'  */
@@ -1526,7 +1514,7 @@ yyreduce:
           {
 	    (yyval.val) = (yyvsp[-1].val);
 	  }
-#line 1530 "itbl-parse.c"
+#line 1518 "itbl-parse.c"
     break;
 
   case 19: /* flagexpr: NUM  */
@@ -1534,7 +1522,7 @@ yyreduce:
           {
 	    (yyval.val) = (yyvsp[0].num);
 	  }
-#line 1538 "itbl-parse.c"
+#line 1526 "itbl-parse.c"
     break;
 
   case 20: /* flags: '*' flagexpr  */
@@ -1543,7 +1531,7 @@ yyreduce:
 	    DBGL2 (("flags=%d\n", (yyvsp[0].val)));
 	    (yyval.val) = (yyvsp[0].val);
 	  }
-#line 1547 "itbl-parse.c"
+#line 1535 "itbl-parse.c"
     break;
 
   case 21: /* flags: %empty  */
@@ -1551,7 +1539,7 @@ yyreduce:
           {
 	    (yyval.val) = 0;
 	  }
-#line 1555 "itbl-parse.c"
+#line 1543 "itbl-parse.c"
     break;
 
   case 22: /* range: ':' NUM '-' NUM  */
@@ -1561,7 +1549,7 @@ yyreduce:
 	    sbit = (yyvsp[-2].num);
 	    ebit = (yyvsp[0].num);
 	  }
-#line 1565 "itbl-parse.c"
+#line 1553 "itbl-parse.c"
     break;
 
   case 23: /* range: %empty  */
@@ -1570,7 +1558,7 @@ yyreduce:
 	    sbit = 31;
 	    ebit = 0;
 	  }
-#line 1574 "itbl-parse.c"
+#line 1562 "itbl-parse.c"
     break;
 
   case 24: /* pnum: PNUM  */
@@ -1579,7 +1567,7 @@ yyreduce:
 	    DBGL2 (("pnum=%d\n",(yyvsp[0].num)));
 	    (yyval.num) = (yyvsp[0].num);
 	  }
-#line 1583 "itbl-parse.c"
+#line 1571 "itbl-parse.c"
     break;
 
   case 25: /* regtype: DREG  */
@@ -1588,7 +1576,7 @@ yyreduce:
 	    DBGL2 (("dreg\n"));
 	    (yyval.num) = DREG;
 	  }
-#line 1592 "itbl-parse.c"
+#line 1580 "itbl-parse.c"
     break;
 
   case 26: /* regtype: CREG  */
@@ -1597,7 +1585,7 @@ yyreduce:
 	    DBGL2 (("creg\n"));
 	    (yyval.num) = CREG;
 	  }
-#line 1601 "itbl-parse.c"
+#line 1589 "itbl-parse.c"
     break;
 
   case 27: /* regtype: GREG  */
@@ -1606,7 +1594,7 @@ yyreduce:
 	    DBGL2 (("greg\n"));
 	    (yyval.num) = GREG;
 	  }
-#line 1610 "itbl-parse.c"
+#line 1598 "itbl-parse.c"
     break;
 
   case 28: /* name: ID  */
@@ -1615,7 +1603,7 @@ yyreduce:
 	    DBGL2 (("name=%s\n",(yyvsp[0].str)));
 	    (yyval.str) = (yyvsp[0].str);
 	  }
-#line 1619 "itbl-parse.c"
+#line 1607 "itbl-parse.c"
     break;
 
   case 29: /* value: NUM  */
@@ -1624,11 +1612,11 @@ yyreduce:
 	    DBGL2 (("val=x%x\n",(yyvsp[0].num)));
 	    (yyval.val) = (yyvsp[0].num);
 	  }
-#line 1628 "itbl-parse.c"
+#line 1616 "itbl-parse.c"
     break;
 
 
-#line 1632 "itbl-parse.c"
+#line 1620 "itbl-parse.c"
 
       default: break;
     }
@@ -1825,9 +1813,8 @@ yyreturn:
 #line 450 "./itbl-parse.y"
 
 
-static int
+static void
 yyerror (const char *msg)
 {
   printf ("line %d: %s\n", insntbl_line, msg);
-  return 0;
 }
