@@ -1,6 +1,6 @@
 /* plugin_test_7_1.c -- a test case for the plugin API with GC.
 
-   Copyright (C) 2010-2020 Free Software Foundation, Inc.
+   Copyright (C) 2010-2022 Free Software Foundation, Inc.
    Written by Rafael Avila de Espindola <espindola@google.com>.
 
    This file is part of gold.
@@ -21,13 +21,23 @@
    MA 02110-1301, USA.  */
 
 int fun1(void);
-void fun2(void);
+int fun2(void);
+void set_x(int y);
 
-void fun2(void)
-{
-}
+#ifndef LTO
+static int x = 0;
 
-int main(void)
+void set_x(int y)
 {
-  return fun1();
+  x = y;
+}
+#endif
+
+int fun1(void)
+{
+#ifndef LTO
+  if (x)
+    return fun2();
+#endif
+  return 0;
 }
