@@ -1,8 +1,8 @@
-/* A Bison parser, made by GNU Bison 3.7.6.  */
+/* A Bison parser, made by GNU Bison 3.7.4.  */
 
 /* Bison implementation for Yacc-like parsers in C
 
-   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2021 Free Software Foundation,
+   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2020 Free Software Foundation,
    Inc.
 
    This program is free software: you can redistribute it and/or modify
@@ -16,7 +16,7 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
 /* As a special exception, you may create a larger work that contains
    part or all of the Bison parser skeleton and distribute that work
@@ -46,10 +46,10 @@
    USER NAME SPACE" below.  */
 
 /* Identify Bison output, and Bison version.  */
-#define YYBISON 30706
+#define YYBISON 30704
 
 /* Bison version string.  */
-#define YYBISON_VERSION "3.7.6"
+#define YYBISON_VERSION "3.7.4"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -70,7 +70,7 @@
 #line 1 "deffilep.y"
  /* deffilep.y - parser for .def files */
 
-/*   Copyright (C) 1995-2021 Free Software Foundation, Inc.
+/*   Copyright (C) 1995-2022 Free Software Foundation, Inc.
 
      This file is part of GNU Binutils.
 
@@ -172,7 +172,7 @@ static void def_version (int, int);
 static void def_directive (char *);
 static void def_aligncomm (char *str, int align);
 static int def_parse (void);
-static int def_error (const char *);
+static void def_error (const char *);
 static int def_lex (void);
 
 static int lex_forced_token = 0;
@@ -424,18 +424,6 @@ typedef int_least16_t yytype_int16;
 typedef short yytype_int16;
 #endif
 
-/* Work around bug in HP-UX 11.23, which defines these macros
-   incorrectly for preprocessor constants.  This workaround can likely
-   be removed in 2023, as HPE has promised support for HP-UX 11.23
-   (aka HP-UX 11i v2) only through the end of 2022; see Table 2 of
-   <https://h20195.www2.hpe.com/V2/getpdf.aspx/4AA4-7673ENW.pdf>.  */
-#ifdef __hpux
-# undef UINT_LEAST8_MAX
-# undef UINT_LEAST16_MAX
-# define UINT_LEAST8_MAX 255
-# define UINT_LEAST16_MAX 65535
-#endif
-
 #if defined __UINT_LEAST8_MAX__ && __UINT_LEAST8_MAX__ <= __INT_MAX__
 typedef __UINT_LEAST8_TYPE__ yytype_uint8;
 #elif (!defined __UINT_LEAST8_MAX__ && defined YY_STDINT_H \
@@ -533,9 +521,9 @@ typedef int yy_state_fast_t;
 
 /* Suppress unused-variable warnings by "using" E.  */
 #if ! defined lint || defined __GNUC__
-# define YY_USE(E) ((void) (E))
+# define YYUSE(E) ((void) (E))
 #else
-# define YY_USE(E) /* empty */
+# define YYUSE(E) /* empty */
 #endif
 
 #if defined __GNUC__ && ! defined __ICC && 407 <= __GNUC__ * 100 + __GNUC_MINOR__
@@ -882,9 +870,9 @@ static const yytype_int16 yypgoto[] =
 };
 
   /* YYDEFGOTO[NTERM-NUM].  */
-static const yytype_uint8 yydefgoto[] =
+static const yytype_int16 yydefgoto[] =
 {
-       0,    14,    15,    58,    59,   128,   129,    62,    63,    56,
+      -1,    14,    15,    58,    59,   128,   129,    62,    63,    56,
       57,    52,    82,    79,    53,    40,    41,    42,   116,   103,
       88,    76,    67,   108,   119,    46,   111
 };
@@ -1057,7 +1045,7 @@ yy_symbol_value_print (FILE *yyo,
                        yysymbol_kind_t yykind, YYSTYPE const * const yyvaluep)
 {
   FILE *yyoutput = yyo;
-  YY_USE (yyoutput);
+  YYUSE (yyoutput);
   if (!yyvaluep)
     return;
 # ifdef YYPRINT
@@ -1065,7 +1053,7 @@ yy_symbol_value_print (FILE *yyo,
     YYPRINT (yyo, yytoknum[yykind], *yyvaluep);
 # endif
   YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
-  YY_USE (yykind);
+  YYUSE (yykind);
   YY_IGNORE_MAYBE_UNINITIALIZED_END
 }
 
@@ -1179,13 +1167,13 @@ static void
 yydestruct (const char *yymsg,
             yysymbol_kind_t yykind, YYSTYPE *yyvaluep)
 {
-  YY_USE (yyvaluep);
+  YYUSE (yyvaluep);
   if (!yymsg)
     yymsg = "Deleting";
   YY_SYMBOL_PRINT (yymsg, yykind, yyvaluep, yylocationp);
 
   YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
-  YY_USE (yykind);
+  YYUSE (yykind);
   YY_IGNORE_MAYBE_UNINITIALIZED_END
 }
 
@@ -1448,367 +1436,367 @@ yyreduce:
   case 4: /* command: NAME opt_name opt_base  */
 #line 144 "deffilep.y"
                                        { def_image_name ((yyvsp[-1].id), (yyvsp[0].vma), 0); }
-#line 1452 "deffilep.c"
+#line 1440 "deffilep.c"
     break;
 
   case 5: /* command: LIBRARY opt_name opt_base  */
 #line 145 "deffilep.y"
                                           { def_image_name ((yyvsp[-1].id), (yyvsp[0].vma), 1); }
-#line 1458 "deffilep.c"
+#line 1446 "deffilep.c"
     break;
 
   case 6: /* command: DESCRIPTION ID  */
 #line 146 "deffilep.y"
                                { def_description ((yyvsp[0].id));}
-#line 1464 "deffilep.c"
+#line 1452 "deffilep.c"
     break;
 
   case 7: /* command: STACKSIZE_K NUMBER opt_number  */
 #line 147 "deffilep.y"
                                               { def_stacksize ((yyvsp[-1].number), (yyvsp[0].number));}
-#line 1470 "deffilep.c"
+#line 1458 "deffilep.c"
     break;
 
   case 8: /* command: HEAPSIZE NUMBER opt_number  */
 #line 148 "deffilep.y"
                                            { def_heapsize ((yyvsp[-1].number), (yyvsp[0].number));}
-#line 1476 "deffilep.c"
+#line 1464 "deffilep.c"
     break;
 
   case 9: /* command: CODE attr_list  */
 #line 149 "deffilep.y"
                                { def_section ("CODE", (yyvsp[0].number));}
-#line 1482 "deffilep.c"
+#line 1470 "deffilep.c"
     break;
 
   case 10: /* command: DATAU attr_list  */
 #line 150 "deffilep.y"
                                  { def_section ("DATA", (yyvsp[0].number));}
-#line 1488 "deffilep.c"
+#line 1476 "deffilep.c"
     break;
 
   case 14: /* command: VERSIONK NUMBER  */
 #line 154 "deffilep.y"
                                 { def_version ((yyvsp[0].number), 0);}
-#line 1494 "deffilep.c"
+#line 1482 "deffilep.c"
     break;
 
   case 15: /* command: VERSIONK NUMBER '.' NUMBER  */
 #line 155 "deffilep.y"
                                            { def_version ((yyvsp[-2].number), (yyvsp[0].number));}
-#line 1500 "deffilep.c"
+#line 1488 "deffilep.c"
     break;
 
   case 16: /* command: DIRECTIVE ID  */
 #line 156 "deffilep.y"
                              { def_directive ((yyvsp[0].id));}
-#line 1506 "deffilep.c"
+#line 1494 "deffilep.c"
     break;
 
   case 17: /* command: ALIGNCOMM anylang_id ',' NUMBER  */
 #line 157 "deffilep.y"
                                                 { def_aligncomm ((yyvsp[-2].id), (yyvsp[0].number));}
-#line 1512 "deffilep.c"
+#line 1500 "deffilep.c"
     break;
 
   case 21: /* expline: opt_name2 opt_equal_name opt_ordinal opt_comma exp_opt_list opt_comma opt_equalequal_name  */
 #line 172 "deffilep.y"
                         { def_exports ((yyvsp[-6].id), (yyvsp[-5].id), (yyvsp[-4].number), (yyvsp[-2].number), (yyvsp[0].id)); }
-#line 1518 "deffilep.c"
+#line 1506 "deffilep.c"
     break;
 
   case 22: /* exp_opt_list: exp_opt opt_comma exp_opt_list  */
 #line 178 "deffilep.y"
                                                { (yyval.number) = (yyvsp[-2].number) | (yyvsp[0].number); }
-#line 1524 "deffilep.c"
+#line 1512 "deffilep.c"
     break;
 
   case 23: /* exp_opt_list: %empty  */
 #line 179 "deffilep.y"
                 { (yyval.number) = 0; }
-#line 1530 "deffilep.c"
+#line 1518 "deffilep.c"
     break;
 
   case 24: /* exp_opt: NONAMEU  */
 #line 182 "deffilep.y"
                                 { (yyval.number) = 1; }
-#line 1536 "deffilep.c"
+#line 1524 "deffilep.c"
     break;
 
   case 25: /* exp_opt: NONAMEL  */
 #line 183 "deffilep.y"
                                 { (yyval.number) = 1; }
-#line 1542 "deffilep.c"
+#line 1530 "deffilep.c"
     break;
 
   case 26: /* exp_opt: CONSTANTU  */
 #line 184 "deffilep.y"
                                 { (yyval.number) = 2; }
-#line 1548 "deffilep.c"
+#line 1536 "deffilep.c"
     break;
 
   case 27: /* exp_opt: CONSTANTL  */
 #line 185 "deffilep.y"
                                 { (yyval.number) = 2; }
-#line 1554 "deffilep.c"
+#line 1542 "deffilep.c"
     break;
 
   case 28: /* exp_opt: DATAU  */
 #line 186 "deffilep.y"
                                 { (yyval.number) = 4; }
-#line 1560 "deffilep.c"
+#line 1548 "deffilep.c"
     break;
 
   case 29: /* exp_opt: DATAL  */
 #line 187 "deffilep.y"
                                 { (yyval.number) = 4; }
-#line 1566 "deffilep.c"
+#line 1554 "deffilep.c"
     break;
 
   case 30: /* exp_opt: PRIVATEU  */
 #line 188 "deffilep.y"
                                 { (yyval.number) = 8; }
-#line 1572 "deffilep.c"
+#line 1560 "deffilep.c"
     break;
 
   case 31: /* exp_opt: PRIVATEL  */
 #line 189 "deffilep.y"
                                 { (yyval.number) = 8; }
-#line 1578 "deffilep.c"
+#line 1566 "deffilep.c"
     break;
 
   case 34: /* impline: ID '=' ID '.' ID '.' ID opt_equalequal_name  */
 #line 198 "deffilep.y"
                  { def_import ((yyvsp[-7].id), (yyvsp[-5].id), (yyvsp[-3].id), (yyvsp[-1].id), -1, (yyvsp[0].id)); }
-#line 1584 "deffilep.c"
+#line 1572 "deffilep.c"
     break;
 
   case 35: /* impline: ID '=' ID '.' ID '.' NUMBER opt_equalequal_name  */
 #line 200 "deffilep.y"
                                  { def_import ((yyvsp[-7].id), (yyvsp[-5].id), (yyvsp[-3].id),  0, (yyvsp[-1].number), (yyvsp[0].id)); }
-#line 1590 "deffilep.c"
+#line 1578 "deffilep.c"
     break;
 
   case 36: /* impline: ID '=' ID '.' ID opt_equalequal_name  */
 #line 202 "deffilep.y"
                  { def_import ((yyvsp[-5].id), (yyvsp[-3].id),	0, (yyvsp[-1].id), -1, (yyvsp[0].id)); }
-#line 1596 "deffilep.c"
+#line 1584 "deffilep.c"
     break;
 
   case 37: /* impline: ID '=' ID '.' NUMBER opt_equalequal_name  */
 #line 204 "deffilep.y"
                  { def_import ((yyvsp[-5].id), (yyvsp[-3].id),	0,  0, (yyvsp[-1].number), (yyvsp[0].id)); }
-#line 1602 "deffilep.c"
+#line 1590 "deffilep.c"
     break;
 
   case 38: /* impline: ID '.' ID '.' ID opt_equalequal_name  */
 #line 206 "deffilep.y"
                  { def_import( 0, (yyvsp[-5].id), (yyvsp[-3].id), (yyvsp[-1].id), -1, (yyvsp[0].id)); }
-#line 1608 "deffilep.c"
+#line 1596 "deffilep.c"
     break;
 
   case 39: /* impline: ID '.' ID opt_equalequal_name  */
 #line 208 "deffilep.y"
                  { def_import ( 0, (yyvsp[-3].id),	0, (yyvsp[-1].id), -1, (yyvsp[0].id)); }
-#line 1614 "deffilep.c"
+#line 1602 "deffilep.c"
     break;
 
   case 42: /* secline: ID attr_list  */
 #line 217 "deffilep.y"
                      { def_section ((yyvsp[-1].id), (yyvsp[0].number));}
-#line 1620 "deffilep.c"
+#line 1608 "deffilep.c"
     break;
 
   case 43: /* secline: ID ID  */
 #line 218 "deffilep.y"
                 { def_section_alt ((yyvsp[-1].id), (yyvsp[0].id));}
-#line 1626 "deffilep.c"
+#line 1614 "deffilep.c"
     break;
 
   case 44: /* attr_list: attr_list opt_comma attr  */
 #line 222 "deffilep.y"
                                  { (yyval.number) = (yyvsp[-2].number) | (yyvsp[0].number); }
-#line 1632 "deffilep.c"
+#line 1620 "deffilep.c"
     break;
 
   case 45: /* attr_list: attr  */
 #line 223 "deffilep.y"
                { (yyval.number) = (yyvsp[0].number); }
-#line 1638 "deffilep.c"
+#line 1626 "deffilep.c"
     break;
 
   case 48: /* opt_number: ',' NUMBER  */
 #line 230 "deffilep.y"
                        { (yyval.number)=(yyvsp[0].number);}
-#line 1644 "deffilep.c"
+#line 1632 "deffilep.c"
     break;
 
   case 49: /* opt_number: %empty  */
 #line 231 "deffilep.y"
                    { (yyval.number)=-1;}
-#line 1650 "deffilep.c"
+#line 1638 "deffilep.c"
     break;
 
   case 50: /* attr: READ  */
 #line 235 "deffilep.y"
                         { (yyval.number) = 1;}
-#line 1656 "deffilep.c"
+#line 1644 "deffilep.c"
     break;
 
   case 51: /* attr: WRITE  */
 #line 236 "deffilep.y"
                         { (yyval.number) = 2;}
-#line 1662 "deffilep.c"
+#line 1650 "deffilep.c"
     break;
 
   case 52: /* attr: EXECUTE  */
 #line 237 "deffilep.y"
                         { (yyval.number)=4;}
-#line 1668 "deffilep.c"
+#line 1656 "deffilep.c"
     break;
 
   case 53: /* attr: SHARED_K  */
 #line 238 "deffilep.y"
                          { (yyval.number)=8;}
-#line 1674 "deffilep.c"
+#line 1662 "deffilep.c"
     break;
 
   case 54: /* keyword_as_name: BASE  */
 #line 242 "deffilep.y"
                       { (yyval.id_const) = "BASE"; }
-#line 1680 "deffilep.c"
+#line 1668 "deffilep.c"
     break;
 
   case 55: /* keyword_as_name: CODE  */
 #line 243 "deffilep.y"
                 { (yyval.id_const) = "CODE"; }
-#line 1686 "deffilep.c"
+#line 1674 "deffilep.c"
     break;
 
   case 56: /* keyword_as_name: CONSTANTU  */
 #line 244 "deffilep.y"
                      { (yyval.id_const) = "CONSTANT"; }
-#line 1692 "deffilep.c"
+#line 1680 "deffilep.c"
     break;
 
   case 57: /* keyword_as_name: CONSTANTL  */
 #line 245 "deffilep.y"
                      { (yyval.id_const) = "constant"; }
-#line 1698 "deffilep.c"
+#line 1686 "deffilep.c"
     break;
 
   case 58: /* keyword_as_name: DATAU  */
 #line 246 "deffilep.y"
                  { (yyval.id_const) = "DATA"; }
-#line 1704 "deffilep.c"
+#line 1692 "deffilep.c"
     break;
 
   case 59: /* keyword_as_name: DATAL  */
 #line 247 "deffilep.y"
                  { (yyval.id_const) = "data"; }
-#line 1710 "deffilep.c"
+#line 1698 "deffilep.c"
     break;
 
   case 60: /* keyword_as_name: DESCRIPTION  */
 #line 248 "deffilep.y"
                        { (yyval.id_const) = "DESCRIPTION"; }
-#line 1716 "deffilep.c"
+#line 1704 "deffilep.c"
     break;
 
   case 61: /* keyword_as_name: DIRECTIVE  */
 #line 249 "deffilep.y"
                      { (yyval.id_const) = "DIRECTIVE"; }
-#line 1722 "deffilep.c"
+#line 1710 "deffilep.c"
     break;
 
   case 62: /* keyword_as_name: EXECUTE  */
 #line 250 "deffilep.y"
                    { (yyval.id_const) = "EXECUTE"; }
-#line 1728 "deffilep.c"
+#line 1716 "deffilep.c"
     break;
 
   case 63: /* keyword_as_name: EXPORTS  */
 #line 251 "deffilep.y"
                    { (yyval.id_const) = "EXPORTS"; }
-#line 1734 "deffilep.c"
+#line 1722 "deffilep.c"
     break;
 
   case 64: /* keyword_as_name: HEAPSIZE  */
 #line 252 "deffilep.y"
                     { (yyval.id_const) = "HEAPSIZE"; }
-#line 1740 "deffilep.c"
+#line 1728 "deffilep.c"
     break;
 
   case 65: /* keyword_as_name: IMPORTS  */
 #line 253 "deffilep.y"
                    { (yyval.id_const) = "IMPORTS"; }
-#line 1746 "deffilep.c"
+#line 1734 "deffilep.c"
     break;
 
   case 66: /* keyword_as_name: NAME  */
 #line 260 "deffilep.y"
                 { (yyval.id_const) = "NAME"; }
-#line 1752 "deffilep.c"
+#line 1740 "deffilep.c"
     break;
 
   case 67: /* keyword_as_name: NONAMEU  */
 #line 261 "deffilep.y"
                    { (yyval.id_const) = "NONAME"; }
-#line 1758 "deffilep.c"
+#line 1746 "deffilep.c"
     break;
 
   case 68: /* keyword_as_name: NONAMEL  */
 #line 262 "deffilep.y"
                    { (yyval.id_const) = "noname"; }
-#line 1764 "deffilep.c"
+#line 1752 "deffilep.c"
     break;
 
   case 69: /* keyword_as_name: PRIVATEU  */
 #line 263 "deffilep.y"
                     { (yyval.id_const) = "PRIVATE"; }
-#line 1770 "deffilep.c"
+#line 1758 "deffilep.c"
     break;
 
   case 70: /* keyword_as_name: PRIVATEL  */
 #line 264 "deffilep.y"
                     { (yyval.id_const) = "private"; }
-#line 1776 "deffilep.c"
+#line 1764 "deffilep.c"
     break;
 
   case 71: /* keyword_as_name: READ  */
 #line 265 "deffilep.y"
                 { (yyval.id_const) = "READ"; }
-#line 1782 "deffilep.c"
+#line 1770 "deffilep.c"
     break;
 
   case 72: /* keyword_as_name: SHARED_K  */
 #line 266 "deffilep.y"
                      { (yyval.id_const) = "SHARED"; }
-#line 1788 "deffilep.c"
+#line 1776 "deffilep.c"
     break;
 
   case 73: /* keyword_as_name: STACKSIZE_K  */
 #line 267 "deffilep.y"
                        { (yyval.id_const) = "STACKSIZE"; }
-#line 1794 "deffilep.c"
+#line 1782 "deffilep.c"
     break;
 
   case 74: /* keyword_as_name: VERSIONK  */
 #line 268 "deffilep.y"
                     { (yyval.id_const) = "VERSION"; }
-#line 1800 "deffilep.c"
+#line 1788 "deffilep.c"
     break;
 
   case 75: /* keyword_as_name: WRITE  */
 #line 269 "deffilep.y"
                  { (yyval.id_const) = "WRITE"; }
-#line 1806 "deffilep.c"
+#line 1794 "deffilep.c"
     break;
 
   case 76: /* opt_name2: ID  */
 #line 272 "deffilep.y"
               { (yyval.id) = (yyvsp[0].id); }
-#line 1812 "deffilep.c"
+#line 1800 "deffilep.c"
     break;
 
   case 77: /* opt_name2: '.' keyword_as_name  */
@@ -1818,7 +1806,7 @@ yyreduce:
 	    sprintf (name, ".%s", (yyvsp[0].id_const));
 	    (yyval.id) = name;
 	  }
-#line 1822 "deffilep.c"
+#line 1810 "deffilep.c"
     break;
 
   case 78: /* opt_name2: '.' opt_name2  */
@@ -1828,7 +1816,7 @@ yyreduce:
 	    sprintf (name, ".%s", (yyvsp[0].id));
 	    (yyval.id) = name;
 	  }
-#line 1832 "deffilep.c"
+#line 1820 "deffilep.c"
     break;
 
   case 79: /* opt_name2: keyword_as_name '.' opt_name2  */
@@ -1838,7 +1826,7 @@ yyreduce:
 	    sprintf (name, "%s.%s", (yyvsp[-2].id_const), (yyvsp[0].id));
 	    (yyval.id) = name;
 	  }
-#line 1842 "deffilep.c"
+#line 1830 "deffilep.c"
     break;
 
   case 80: /* opt_name2: ID '.' opt_name2  */
@@ -1848,73 +1836,73 @@ yyreduce:
 	    sprintf (name, "%s.%s", (yyvsp[-2].id), (yyvsp[0].id));
 	    (yyval.id) = name;
 	  }
-#line 1852 "deffilep.c"
+#line 1840 "deffilep.c"
     break;
 
   case 81: /* opt_name: opt_name2  */
 #line 299 "deffilep.y"
                     { (yyval.id) = (yyvsp[0].id); }
-#line 1858 "deffilep.c"
+#line 1846 "deffilep.c"
     break;
 
   case 82: /* opt_name: %empty  */
 #line 300 "deffilep.y"
                         { (yyval.id) = ""; }
-#line 1864 "deffilep.c"
+#line 1852 "deffilep.c"
     break;
 
   case 83: /* opt_equalequal_name: EQUAL ID  */
 #line 303 "deffilep.y"
                                 { (yyval.id) = (yyvsp[0].id); }
-#line 1870 "deffilep.c"
+#line 1858 "deffilep.c"
     break;
 
   case 84: /* opt_equalequal_name: %empty  */
 #line 304 "deffilep.y"
                                                                 { (yyval.id) = 0; }
-#line 1876 "deffilep.c"
+#line 1864 "deffilep.c"
     break;
 
   case 85: /* opt_ordinal: '@' NUMBER  */
 #line 308 "deffilep.y"
                          { (yyval.number) = (yyvsp[0].number);}
-#line 1882 "deffilep.c"
+#line 1870 "deffilep.c"
     break;
 
   case 86: /* opt_ordinal: %empty  */
 #line 309 "deffilep.y"
                          { (yyval.number) = -1;}
-#line 1888 "deffilep.c"
+#line 1876 "deffilep.c"
     break;
 
   case 87: /* opt_equal_name: '=' opt_name2  */
 #line 313 "deffilep.y"
                         { (yyval.id) = (yyvsp[0].id); }
-#line 1894 "deffilep.c"
+#line 1882 "deffilep.c"
     break;
 
   case 88: /* opt_equal_name: %empty  */
 #line 314 "deffilep.y"
                         { (yyval.id) =	0; }
-#line 1900 "deffilep.c"
+#line 1888 "deffilep.c"
     break;
 
   case 89: /* opt_base: BASE '=' VMA  */
 #line 317 "deffilep.y"
                         { (yyval.vma) = (yyvsp[0].vma);}
-#line 1906 "deffilep.c"
+#line 1894 "deffilep.c"
     break;
 
   case 90: /* opt_base: %empty  */
 #line 318 "deffilep.y"
                 { (yyval.vma) = (bfd_vma) -1;}
-#line 1912 "deffilep.c"
+#line 1900 "deffilep.c"
     break;
 
   case 91: /* anylang_id: ID  */
 #line 321 "deffilep.y"
                         { (yyval.id) = (yyvsp[0].id); }
-#line 1918 "deffilep.c"
+#line 1906 "deffilep.c"
     break;
 
   case 92: /* anylang_id: '.' ID  */
@@ -1924,7 +1912,7 @@ yyreduce:
 	    sprintf (id, ".%s", (yyvsp[0].id));
 	    (yyval.id) = id;
 	  }
-#line 1928 "deffilep.c"
+#line 1916 "deffilep.c"
     break;
 
   case 93: /* anylang_id: anylang_id '.' opt_digits opt_id  */
@@ -1934,47 +1922,47 @@ yyreduce:
 	    sprintf (id, "%s.%s%s", (yyvsp[-3].id), (yyvsp[-1].digits), (yyvsp[0].id));
 	    (yyval.id) = id;
 	  }
-#line 1938 "deffilep.c"
+#line 1926 "deffilep.c"
     break;
 
   case 94: /* opt_digits: DIGITS  */
 #line 336 "deffilep.y"
                         { (yyval.digits) = (yyvsp[0].digits); }
-#line 1944 "deffilep.c"
+#line 1932 "deffilep.c"
     break;
 
   case 95: /* opt_digits: %empty  */
 #line 337 "deffilep.y"
                         { (yyval.digits) = ""; }
-#line 1950 "deffilep.c"
+#line 1938 "deffilep.c"
     break;
 
   case 96: /* opt_id: ID  */
 #line 340 "deffilep.y"
                         { (yyval.id) = (yyvsp[0].id); }
-#line 1956 "deffilep.c"
+#line 1944 "deffilep.c"
     break;
 
   case 97: /* opt_id: %empty  */
 #line 341 "deffilep.y"
                         { (yyval.id) = ""; }
-#line 1962 "deffilep.c"
+#line 1950 "deffilep.c"
     break;
 
   case 98: /* NUMBER: DIGITS  */
 #line 344 "deffilep.y"
                         { (yyval.number) = strtoul ((yyvsp[0].digits), 0, 0); }
-#line 1968 "deffilep.c"
+#line 1956 "deffilep.c"
     break;
 
   case 99: /* VMA: DIGITS  */
 #line 346 "deffilep.y"
                         { (yyval.vma) = (bfd_vma) strtoull ((yyvsp[0].digits), 0, 0); }
-#line 1974 "deffilep.c"
+#line 1962 "deffilep.c"
     break;
 
 
-#line 1978 "deffilep.c"
+#line 1966 "deffilep.c"
 
       default: break;
     }
@@ -3085,12 +3073,11 @@ def_aligncomm (char *str, int align)
     }
 }
 
-static int
+static void
 def_error (const char *err)
 {
   einfo ("%P: %s:%d: %s\n",
 	 def_filename ? def_filename : "<unknown-file>", linenumber, err);
-  return 0;
 }
 
 
