@@ -1,5 +1,5 @@
 /* ldlang.h - linker command language support
-   Copyright (C) 1991-2019 Free Software Foundation, Inc.
+   Copyright (C) 1991-2022 Free Software Foundation, Inc.
 
    This file is part of the GNU Binutils.
 
@@ -23,6 +23,8 @@
 
 #define DEFAULT_MEMORY_REGION   "*default*"
 
+#define SECTION_NAME_MAP_LENGTH (16)
+
 typedef enum
 {
   lang_input_file_is_l_enum,
@@ -63,7 +65,7 @@ typedef struct memory_region_struct
   union lang_statement_union *last_os;
   flagword flags;
   flagword not_flags;
-  bfd_boolean had_full_message;
+  bool had_full_message;
 } lang_memory_region_type;
 
 enum statement_enum
@@ -119,7 +121,8 @@ enum section_type
   first_overlay_section,
   overlay_section,
   noload_section,
-  noalloc_section
+  noalloc_section,
+  readonly_section
 };
 
 /* This structure holds a list of program headers describing
@@ -129,7 +132,7 @@ typedef struct lang_output_section_phdr_list
 {
   struct lang_output_section_phdr_list *next;
   const char *name;
-  bfd_boolean used;
+  bool used;
 } lang_output_section_phdr_list;
 
 typedef struct lang_output_section_statement_struct
@@ -156,6 +159,9 @@ typedef struct lang_output_section_statement_struct
 
   lang_output_section_phdr_list *phdrs;
 
+  /* Used by ELF SHF_LINK_ORDER sorting.  */
+  void *data;
+
   unsigned int block_value;
   int constraint;
   flagword flags;
@@ -171,6 +177,9 @@ typedef struct lang_output_section_statement_struct
   unsigned int after_end : 1;
   /* If this section uses the alignment of its input sections.  */
   unsigned int align_lma_with_input : 1;
+  /* If script has duplicate output section statements of the same name
+     create duplicate output sections.  */
+  unsigned int dup_output : 1;
 } lang_output_section_statement_type;
 
 typedef struct
@@ -269,7 +278,7 @@ struct lang_input_statement_flags
   /* Set if reloading an archive or --as-needed lib.  */
   unsigned int reload : 1;
 
-#ifdef ENABLE_PLUGINS
+#if BFD_SUPPORTS_PLUGINS
   /* Set if the file was claimed by a plugin.  */
   unsigned int claimed : 1;
 
@@ -278,7 +287,7 @@ struct lang_input_statement_flags
 
   /* Set if added by the lto plugin add_input_file callback.  */
   unsigned int lto_output : 1;
-#endif /* ENABLE_PLUGINS */
+#endif /* BFD_SUPPORTS_PLUGINS */
 
   /* Head of list of pushed flags.  */
   struct lang_input_statement_flags *pushed;
@@ -293,9 +302,14 @@ typedef struct lang_input_statement_struct
      Usually the same as filename, but for a file spec'd with
      -l this is the -l switch itself rather than the filename.  */
   const char *local_sym_name;
+  /* Extra search path. Used to find a file relative to the
+     directory of the current linker script.  */
+  const char *extra_search_path;
 
   bfd *the_bfd;
 
+  ctf_archive_t *the_ctf;
+
   struct flag_info *section_flag_list;
 
   /* Next pointer for file_chain statement list.  */
@@ -313,6 +327,7 @@ typedef struct
 {
   lang_statement_header_type header;
   asection *section;
+  void *pattern;
 } lang_input_section_type;
 
 struct map_symbol_def {
@@ -329,28 +344,32 @@ typedef struct input_section_userdata_struct
   unsigned long map_symbol_def_count;
 } input_section_userdata_type;
 
-#define get_userdata(x) ((x)->userdata)
-
+static inline bool
+bfd_input_just_syms (const bfd *abfd)
+{
+  lang_input_statement_type *is = bfd_usrdata (abfd);
+  return is != NULL && is->flags.just_syms;
+}
 
 typedef struct lang_wild_statement_struct lang_wild_statement_type;
 
 typedef void (*callback_t) (lang_wild_statement_type *, struct wildcard_list *,
-			    asection *, struct flag_info *,
-			    lang_input_statement_type *, void *);
+			    asection *, lang_input_statement_type *, void *);
 
 typedef void (*walk_wild_section_handler_t) (lang_wild_statement_type *,
 					     lang_input_statement_type *,
 					     callback_t callback,
 					     void *data);
 
-typedef bfd_boolean (*lang_match_sec_type_func) (bfd *, const asection *,
-						 bfd *, const asection *);
+typedef bool (*lang_match_sec_type_func) (bfd *, const asection *,
+					  bfd *, const asection *);
 
 /* Binary search tree structure to efficiently sort sections by
    name.  */
 typedef struct lang_section_bst
 {
   asection *section;
+  void *pattern;
   struct lang_section_bst *left;
   struct lang_section_bst *right;
 } lang_section_bst_type;
@@ -359,9 +378,9 @@ struct lang_wild_statement_struct
 {
   lang_statement_header_type header;
   const char *filename;
-  bfd_boolean filenames_sorted;
+  bool filenames_sorted;
   struct wildcard_list *section_list;
-  bfd_boolean keep_sections;
+  bool keep_sections;
   lang_statement_list_type children;
   struct name_list *exclude_name_list;
 
@@ -403,7 +422,7 @@ typedef struct
 {
   lang_statement_header_type header;
   const char *where;
-  bfd_boolean is_before;
+  bool is_before;
 } lang_insert_statement_type;
 
 typedef union lang_statement_union
@@ -433,8 +452,8 @@ struct lang_phdr
   struct lang_phdr *next;
   const char *name;
   unsigned long type;
-  bfd_boolean filehdr;
-  bfd_boolean phdrs;
+  bool filehdr;
+  bool phdrs;
   etree_type *at;
   etree_type *flags;
 };
@@ -454,7 +473,7 @@ struct lang_nocrossrefs
 {
   struct lang_nocrossrefs *next;
   lang_nocrossref_type *list;
-  bfd_boolean onlyfirst;
+  bool onlyfirst;
 };
 
 /* This structure is used to hold a list of input section names which
@@ -492,16 +511,19 @@ extern const char *output_target;
 extern lang_output_section_statement_type *abs_output_section;
 extern lang_statement_list_type lang_os_list;
 extern struct lang_input_statement_flags input_flags;
-extern bfd_boolean lang_has_input_file;
+extern bool lang_has_input_file;
+extern lang_statement_list_type statement_list;
 extern lang_statement_list_type *stat_ptr;
-extern bfd_boolean delete_output_file_on_failure;
+extern bool delete_output_file_on_failure;
 
 extern struct bfd_sym_chain entry_symbol;
 extern const char *entry_section;
-extern bfd_boolean entry_from_cmdline;
+extern bool entry_from_cmdline;
 extern lang_statement_list_type file_chain;
 extern lang_statement_list_type input_file_chain;
 
+extern struct bfd_elf_dynamic_list **current_dynamic_list_p;
+
 extern int lang_statement_iteration;
 extern struct asneeded_minfo **asneeded_list_tail;
 
@@ -512,7 +534,7 @@ extern void lang_init
 extern void lang_finish
   (void);
 extern lang_memory_region_type * lang_memory_region_lookup
-  (const char * const, bfd_boolean);
+  (const char * const, bool);
 extern void lang_memory_region_alias
   (const char *, const char *);
 extern void lang_map
@@ -527,19 +549,19 @@ extern lang_output_section_statement_type *lang_enter_output_section_statement
 extern void lang_final
   (void);
 extern void lang_relax_sections
-  (bfd_boolean);
+  (bool);
 extern void lang_process
   (void);
 extern void lang_section_start
   (const char *, union etree_union *, const segment_type *);
 extern void lang_add_entry
-  (const char *, bfd_boolean);
+  (const char *, bool);
 extern void lang_default_entry
   (const char *);
 extern void lang_add_target
   (const char *);
 extern void lang_add_wild
-  (struct wildcard_spec *, struct wildcard_list *, bfd_boolean);
+  (struct wildcard_spec *, struct wildcard_list *, bool);
 extern void lang_add_map
   (const char *);
 extern void lang_add_fill
@@ -551,7 +573,7 @@ extern void lang_add_attribute
 extern void lang_startup
   (const char *);
 extern void lang_float
-  (bfd_boolean);
+  (bool);
 extern void lang_leave_output_section_statement
   (fill_type *, const char *, lang_output_section_phdr_list *,
    const char *);
@@ -568,12 +590,12 @@ extern asection *section_for_dot
 
 #define LANG_FOR_EACH_INPUT_STATEMENT(statement)			\
   lang_input_statement_type *statement;					\
-  for (statement = &file_chain.head->input_statement;			\
+  for (statement = (lang_input_statement_type *) file_chain.head;	\
        statement != NULL;						\
        statement = statement->next)
 
 #define lang_output_section_find(NAME) \
-  lang_output_section_statement_lookup (NAME, 0, FALSE)
+  lang_output_section_statement_lookup (NAME, 0, 0)
 
 extern void lang_process
   (void);
@@ -592,11 +614,11 @@ extern void lang_add_keepsyms_file
 extern lang_output_section_statement_type *lang_output_section_get
   (const asection *);
 extern lang_output_section_statement_type *lang_output_section_statement_lookup
-  (const char *, int, bfd_boolean);
+  (const char *, int, int);
 extern lang_output_section_statement_type *next_matching_output_section_statement
   (lang_output_section_statement_type *, int);
 extern void ldlang_add_undef
-  (const char *const, bfd_boolean);
+  (const char *const, bool);
 extern void ldlang_add_require_defined
   (const char *const);
 extern void lang_add_output_format
@@ -625,9 +647,9 @@ extern void lang_clear_os_map
 extern void dprint_statement
   (lang_statement_union_type *, int);
 extern void lang_size_sections
-  (bfd_boolean *, bfd_boolean);
+  (bool *, bool);
 extern void one_lang_size_sections_pass
-  (bfd_boolean *, bfd_boolean);
+  (bool *, bool);
 extern void lang_add_insert
   (const char *, int);
 extern void lang_enter_group
@@ -635,10 +657,10 @@ extern void lang_enter_group
 extern void lang_leave_group
   (void);
 extern void lang_add_section
-  (lang_statement_list_type *, asection *,
+  (lang_statement_list_type *, asection *, struct wildcard_list *,
    struct flag_info *, lang_output_section_statement_type *);
 extern void lang_new_phdr
-  (const char *, etree_type *, bfd_boolean, bfd_boolean, etree_type *,
+  (const char *, etree_type *, bool, bool, etree_type *,
    etree_type *);
 extern void lang_add_nocrossref
   (lang_nocrossref_type *);
@@ -655,14 +677,15 @@ extern void lang_leave_overlay
    lang_output_section_phdr_list *, const char *);
 
 extern struct bfd_elf_version_expr *lang_new_vers_pattern
-  (struct bfd_elf_version_expr *, const char *, const char *, bfd_boolean);
+  (struct bfd_elf_version_expr *, const char *, const char *, bool);
 extern struct bfd_elf_version_tree *lang_new_vers_node
   (struct bfd_elf_version_expr *, struct bfd_elf_version_expr *);
 extern struct bfd_elf_version_deps *lang_add_vers_depend
   (struct bfd_elf_version_deps *, const char *);
 extern void lang_register_vers_node
   (const char *, struct bfd_elf_version_tree *, struct bfd_elf_version_deps *);
-extern void lang_append_dynamic_list (struct bfd_elf_version_expr *);
+extern void lang_append_dynamic_list (struct bfd_elf_dynamic_list **,
+				      struct bfd_elf_version_expr *);
 extern void lang_append_dynamic_list_cpp_typeinfo (void);
 extern void lang_append_dynamic_list_cpp_new (void);
 extern void lang_add_unique
@@ -670,12 +693,20 @@ extern void lang_add_unique
 extern const char *lang_get_output_target
   (void);
 extern void add_excluded_libs (const char *);
-extern bfd_boolean load_symbols
+extern bool load_symbols
   (lang_input_statement_type *, lang_statement_list_type *);
 
-extern bfd_boolean
+struct elf_sym_strtab;
+struct elf_strtab_hash;
+extern void ldlang_ctf_acquire_strings
+  (struct elf_strtab_hash *);
+extern void ldlang_ctf_new_dynsym
+  (int symidx, struct elf_internal_sym *);
+extern void ldlang_write_ctf_late
+  (void);
+extern bool
 ldlang_override_segment_assignment
-  (struct bfd_link_info *, bfd *, asection *, asection *, bfd_boolean);
+  (struct bfd_link_info *, bfd *, asection *, asection *, bool);
 
 extern void
 lang_ld_feature (char *);
@@ -686,4 +717,7 @@ lang_print_memory_usage (void);
 extern void
 lang_add_gc_name (const char *);
 
+extern bool
+print_one_symbol (struct bfd_link_hash_entry *hash_entry, void *ptr);
+
 #endif
